/*
 * FileMatcher.java
 *
 * Copyright (c) 2005 TopCoder, Inc., All Rights Reserved
 */
package com.topcoder.file.statistics;

import java.io.File;
import java.io.IOException;


/**
 * <p>
 * FileMatcher defines the contract to match a certain file, in order for an attaching FileProcessor to process the
 * file.
 * </p>
 * 
 * <p>
 * All implementations should have a constructor with a Property as an argument in order to reflect from configuration
 * file. This requirement can be dropped if it's not necessary to use this way.
 * </p>
 * 
 * <p>
 * Implementations are advised to be stateless and thread-safe. But it's not a requirement.
 * </p>
 *
 * @author WishingBone, TCSDEVELOPER
 * @version 1.0
 */
public interface FileMatcher {
    /**
     * <p>
     * Determines if the file can be processed by the processor that this matcher is associated with.
     * </p>
     *
     * @param file the file to match
     *
     * @return whether the file matches
     *
     * @throws NullPointerException if file is null
     * @throws IOException if I/O operation fails
     * @throws FileMatchingException if error occurs in file matching
     */
    boolean match(File file) throws IOException, FileMatchingException;
}
