/*
 * TextFileMatcher.java
 *
 * Copyright (c) 2005 TopCoder, Inc., All Rights Reserved
 */
package com.topcoder.file.statistics.matcher;

import com.topcoder.util.config.Property;


/**
 * <p>
 * Concrete implementation of the FileCategoryMatcher class that matches text files.
 * </p>
 * 
 * <p>
 * It does not need any configuration. However constructor is maintained to accept property argument for reflection
 * purpose.
 * </p>
 * 
 * <p>
 * This class is stateless and thread-safe.
 * </p>
 *
 * @author WishingBone, TCSDEVELOPER
 * @version 1.0
 */
public class TextFileMatcher extends FileCategoryMatcher {
    /**
     * <p>
     * Default constructor. Does nothing.
     * </p>
     */
    public TextFileMatcher() {
    }

    /**
     * <p>
     * Constructor that obeys the reflection contract. Does nothing.
     * </p>
     *
     * @param property the property to configure from
     *
     * @throws NullPointerException if property is null
     */
    public TextFileMatcher(Property property) {
        if (property == null) {
            throw new NullPointerException("property is null");
        }
    }

    /**
     * <p>
     * This method simply returns the negation of isBinary to match text files.
     * </p>
     *
     * @param isBinary whether the file is binary
     *
     * @return the negation of isBinary boolean
     */
    protected boolean match(boolean isBinary) {
        return !isBinary;
    }
}
