/*
 * ArchiveExtractorBaseTest.java
 *
 * Copyright (c) 2005 TopCoder, Inc., All Rights Reserved
 */

package com.topcoder.file.statistics;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import com.topcoder.util.config.Property;
import com.topcoder.file.statistics.extractor.ArchiveExtractorBase;
import com.topcoder.file.statistics.matcher.AnyFileMatcher;
import java.io.File;
import java.io.IOException;

/**
 * Unit tests for ArchiveExtractorBase implementation.
 *
 * @author TCSDEVELOPER
 * @version 2.0c
 */
public class ArchiveExtractorBaseTest extends TestCase {
    /**
     * The ArchiveExtractorBase instance to test against.
     */
    private ArchiveExtractorBase extractor = null;
    
    /**
     * The file matcher associated with the extractor.
     */
    private FileMatcher matcher = null;
    
    /**
     * The path separator associated with the extractor.
     */
    private static final char pathSeparator = '?';
    
    /**
     * Prepares an ArchiveExtractorBase instance for testing.
     */
    protected void setUp() throws Exception {
        matcher = new AnyFileMatcher();
        extractor = new SimpleArchiveExtractorBase(matcher, pathSeparator);
    }
    
    /**
     * Creates a test suite for the tests in this test case.
     *
     * @return a TestSuite for this test case
     */
    public static Test suite() {
        TestSuite suite = new TestSuite(ArchiveExtractorBaseTest.class);
        
        return suite;
    }
    
    /**
     * Test of getFileMatcher method. Verifies if the matcher specified in the constructor is returned.
     */
    public void testGetFileMatcher() {
        assertEquals("Returns an incorrect file matcher", matcher, extractor.getFileMatcher());
    }
    
    /**
     * Test of getPathSeparator method. Verifies if the path separator specified in the constructor is returned.
     */
    public void testGetPathSeparator() {
        assertEquals("Returns an incorrect path separator", pathSeparator, extractor.getPathSeparator());
    }
    
    /**
     * A simple implementation of the ArchiveExtractorBase.
     */
    private class SimpleArchiveExtractorBase extends ArchiveExtractorBase {
        /**
         * Constructor with the given pathSeparator and file matcher. Just propagates to the super constructor.
         *
         * @param matcher the file matcher
         * @param pathSeparator the path separator
         * @throws NullPointerException if matcher is null
         */
        public SimpleArchiveExtractorBase(FileMatcher matcher, char pathSeparator) {
            super(matcher, pathSeparator);
        }
        
        /**
         * Constructor with the given property. Just propagates to the super constructor.
         *
         * @param property the property to configure from
         * @throws NullPointerException if property is null
         * @throws ConfigurationException if any error occurs in configuring the extractor
         */
        public SimpleArchiveExtractorBase(Property property) throws ConfigurationException {
            super(property);
        }
        
        /**
         * Extracts the archive file from source into the target directory. Does nothing.
         *
         * @param source the source archive file
         * @param target the target directory
         * @throws NullPointerException if either source or target is null
         * @throws IOException if I/O operation fails (including source/target not exist or target is not a directory)
         * @throws ArchiveExtractingException to encapsulate any implementation specific errors
         */
        public void extract(File source, File target) throws IOException, ArchiveExtractingException {
        }
    }
    
    
}
