/*
 * FileNameMatcherTest.java
 *
 * Copyright (c) 2005 TopCoder, Inc., All Rights Reserved
 */
package com.topcoder.file.statistics;

import com.topcoder.file.statistics.matcher.FileNameMatcher;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import java.io.File;


/**
 * Unit tests for FileNameMatcher implementation.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class FileNameMatcherTest extends TestCase {
    /**
     * The filename passed to the match() method.
     */
    private static final String FILENAME = "filename";

    /**
     * The FileNameMatcher instance to test against.
     */
    private SimpleFileNameMatcher matcher = null;

    /**
     * Creates a test suite for the tests in this test case.
     *
     * @return a TestSuite for this test case
     */
    public static Test suite() {
        TestSuite suite = new TestSuite(FileNameMatcherTest.class);

        return suite;
    }

    /**
     * Prepares a FileNameMatcher instance for testing.
     */
    public void setUp() {
        matcher = new SimpleFileNameMatcher();
    }

    /**
     * Tests the accessibility of default constructor.
     */
    public void testConstructor_Default() {
        new SimpleFileNameMatcher();
    }

    /**
     * Test of match method with null file. Expects NullPointerException.
     *
     * @throws Exception if any unexpected exception occurs.
     */
    public void testMatch_NullFile() throws Exception {
        try {
            matcher.match((File) null);
            fail("Matches a null file");
        } catch (NullPointerException e) {
            // good
        }
    }

    /**
     * Test of match method with non-null file. Verifies if the filename of the file was passed to the abstract match()
     * method. Also verifies if it returns the result of the abstract match() method.
     *
     * @throws Exception if any unexpected exception occurs.
     */
    public void testMatch_NonNullFile() throws Exception {
        matcher.setMatchResult(true);
        assertTrue("Fails to match file", matcher.match(new File("a/b/c/" + FILENAME)));
        assertEquals("Fails to match file", FILENAME, matcher.getFilename());
    }

    /**
     * A simple implementation of the FileNameMatcher class for testing purpose. Two additional methods are provided to
     * set the matching result of the match() method, and get the filename passed to the match() method.
     */
    private class SimpleFileNameMatcher extends FileNameMatcher {
        /**
         * The matching result of the match() method. It can be changed by its setter method.
         */
        private boolean matchResult = false;

        /**
         * The last filename passed to the match() method. It is updated once match() method is called.
         */
        private String filename = null;

        /**
         * Default constructor. Does nothing.
         */
        public SimpleFileNameMatcher() {
            super();
        }

        /**
         * Sets the matching result of the match() method.
         *
         * @param matchResult the matching result of the match() method.
         */
        public void setMatchResult(boolean matchResult) {
            this.matchResult = matchResult;
        }

        /**
         * Returns the last filename passed to the match() method. It can be null if match() method is not called.
         *
         * @return the last filename passed to the match() method.
         */
        public String getFilename() {
            return filename;
        }

        /**
         * <p>
         * Determines whether the file matches based on the given filename. The result depends on the status set in the
         * setMatchResult() method. In addition, it saves the passed filename.
         * </p>
         *
         * @param filename the filename to match
         *
         * @return whether the filename matches
         */
        protected boolean match(String filename) {
            this.filename = filename;
            return matchResult;
        }
    }
}
