/*
 * MetricTest.java
 *
 * Copyright (c) 2005 TopCoder, Inc., All Rights Reserved
 */
package com.topcoder.file.statistics;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;


/**
 * Unit tests for Metric implementation.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class MetricTest extends TestCase {
    /**
     * The name of the metric for testing.
     */
    private static final String NAME = "name";

    /**
     * The display name of the metric for testing.
     */
    private static final String DISPLAY_NAME = "displayName";

    /**
     * The description of the metric for testing.
     */
    private static final String DESCRIPTION = "description";

    /**
     * The Metric instance to test against.
     */
    private Metric metric = null;

    /**
     * Creates a test suite for the tests in this test case.
     *
     * @return a TestSuite for this test case
     */
    public static Test suite() {
        TestSuite suite = new TestSuite(MetricTest.class);

        return suite;
    }

    /**
     * Prepares a Metric instance for testing.
     */
    public void setUp() {
        metric = new Metric(NAME, DISPLAY_NAME, DESCRIPTION);
    }

    /**
     * Test of constructor with null name. Expects NullPointerException.
     */
    public void testConstructor_NullName() {
        try {
            new Metric(null, DISPLAY_NAME, DESCRIPTION);
            fail("Creates Metric with null name");
        } catch (NullPointerException e) {
            // good
        }
    }

    /**
     * Test of constructor with empty name. Expects IllegalArgumentException.
     */
    public void testConstructor_EmptyName() {
        try {
            new Metric("", DISPLAY_NAME, DESCRIPTION);
            fail("Creates Metric with empty name");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * Test of constructor with null display name. Expects NullPointerException.
     */
    public void testConstructor_NullDisplayName() {
        try {
            new Metric(NAME, null, DESCRIPTION);
            fail("Creates Metric with null display name");
        } catch (NullPointerException e) {
            // good
        }
    }

    /**
     * Test of constructor with empty display name. Expects IllegalArgumentException.
     */
    public void testConstructor_EmptyDisplayName() {
        try {
            new Metric(NAME, "", DESCRIPTION);
            fail("Creates Metric with empty display name");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * Test of constructor with null description. Expects NullPointerException.
     */
    public void testConstructor_NullDescription() {
        try {
            new Metric(NAME, DISPLAY_NAME, null);
            fail("Creates Metric with null description");
        } catch (NullPointerException e) {
            // good
        }
    }

    /**
     * Test of constructor with empty description. Expects IllegalArgumentException.
     */
    public void testConstructor_EmptyDescription() {
        try {
            new Metric(NAME, DISPLAY_NAME, "");
            fail("Creates Metric with empty description");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * Test of getName method. Verifies if it returns the name set in constructor.
     */
    public void testGetName() {
        assertEquals("Returns an incorrect name", NAME, metric.getName());
    }

    /**
     * Test of getDisplayName method. Verifies if it returns the display name set in constructor.
     */
    public void testGetDisplayName() {
        assertEquals("Returns an incorrect display name", DISPLAY_NAME, metric.getDisplayName());
    }

    /**
     * Test of getDescription method. Verifies if it returns the description set in constructor.
     */
    public void testGetDescription() {
        assertEquals("Returns an incorrect description", DESCRIPTION, metric.getDescription());
    }

    /**
     * Test of equals method with null object. Verifies if false is returned.
     */
    public void testEquals_NullObject() {
        assertFalse("Returns true with null object", metric.equals(null));
    }

    /**
     * Test of equals method with non-Metric object. Verifies if false is returned.
     */
    public void testEquals_NonMetricObject() {
        assertFalse("Returns true with non-Metric object", metric.equals("non-Metric"));
    }

    /**
     * Test of equals method with Metric object of different name. Verifies if false is returned.
     */
    public void testEquals_DiffName() {
        assertFalse("Returns true with Metric object of different name",
            metric.equals(new Metric("different", DISPLAY_NAME, DESCRIPTION)));
    }

    /**
     * Test of equals method with Metric object of same name. Verifies if true is returned.
     */
    public void testEquals_SameName() {
        assertTrue("Returns false with Metric object of same name",
            metric.equals(new Metric(NAME, "different", "different")));
    }

    /**
     * Test of hashCode method. Verifies if it returns the hash code of the name.
     */
    public void testHashCode() {
        assertEquals("Returns an incorrect hash code", NAME.hashCode(), metric.hashCode());
    }
}
